@@ -12,9 +12,7 @@ class HTTPException(StarletteHTTPException):
         detail: Any = None,
         headers: Optional[Dict[str, Any]] = None,
     ) -> None:
-        super().__init__(
-            status_code=status_code, detail=detail, headers=headers  # type: ignore
-        )
+        super().__init__(status_code=status_code, detail=detail, headers=headers)
 
 
 RequestErrorModel: Type[BaseModel] = create_model("Request")
